@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::Schema::ReportsDB::Result::Notification::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Tapper::Schema::ReportsDB::Result::Notification::VERSION = '4.0.2';
+  $Tapper::Schema::ReportsDB::Result::Notification::VERSION = '4.1.0';
 }
 
 use strict;
@@ -16,7 +16,7 @@ __PACKAGE__->load_components(qw/InflateColumn::DateTime Core/);
 __PACKAGE__->table("notification");
 __PACKAGE__->add_columns
     ( "id",         { data_type => "INT",       default_value => undef,                is_nullable => 0, size => 11, is_auto_increment => 1, },
-      "user_id",    { data_type => "INT",       default_value => undef,                is_nullable => 1, size => 11, is_foreign_key    => 1, },
+      "owner_id",   { data_type => "INT",       default_value => undef,                is_nullable => 1, size => 11, is_foreign_key    => 1, extra => { renamed_from => 'user_id'  }, },
       "persist",    { data_type => "INT",       default_value => undef,                is_nullable => 1, size => 1, },
       "event",      { data_type => "VARCHAR",   default_value => undef,                is_nullable => 0, size => 255, },    # subscribe to this event type
       "filter",     { data_type => "TEXT",      default_value => undef,                is_nullable => 0,  },  # data for check handler
@@ -28,7 +28,7 @@ __PACKAGE__->add_columns
 (my $basepkg = __PACKAGE__) =~ s/::\w+$//;
 
 __PACKAGE__->set_primary_key("id");
-__PACKAGE__->belongs_to( user => "${basepkg}::User", { 'foreign.id' => 'self.user_id' });
+__PACKAGE__->belongs_to( owner => "${basepkg}::Owner", { 'foreign.id' => 'self.owner_id' });
 
 
 1;
