@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::Schema::ReportsDB::Result::ReportComment::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Tapper::Schema::ReportsDB::Result::ReportComment::VERSION = '4.0.2';
+  $Tapper::Schema::ReportsDB::Result::ReportComment::VERSION = '4.1.0';
 }
 
 use strict;
@@ -17,7 +17,7 @@ __PACKAGE__->add_columns
     (
      "id",         { data_type => "INT",      default_value => undef,  is_nullable => 0, size => 11, is_auto_increment => 1,     },
      "report_id",  { data_type => "INT",      default_value => undef,  is_nullable => 0, size => 11, is_foreign_key => 1,        },
-     "user_id",    { data_type => "INT",      default_value => undef,  is_nullable => 1, size => 11, is_foreign_key => 1,        },
+     "owner_id",   { data_type => "INT",      default_value => undef,  is_nullable => 1, size => 11, is_foreign_key => 1, extra => { renamed_from => 'user_id'  }, },
      "succession", { data_type => "INT",      default_value => undef,  is_nullable => 1, size => 10,                             },
      "comment",    { data_type => "TEXT",     default_value => "",     is_nullable => 0,                                         },
      "created_at", { data_type => "DATETIME", default_value => undef,  is_nullable => 0, set_on_create => 1,                     },
@@ -27,7 +27,7 @@ __PACKAGE__->add_columns
 __PACKAGE__->set_primary_key("id");
 
 __PACKAGE__->belongs_to   ( report => 'Tapper::Schema::ReportsDB::Result::Report', { 'foreign.id' => 'self.report_id' });
-__PACKAGE__->belongs_to   ( user   => 'Tapper::Schema::ReportsDB::Result::User',   { 'foreign.id' => 'self.user_id' });
+__PACKAGE__->belongs_to   ( owner  => 'Tapper::Schema::ReportsDB::Result::Owner',  { 'foreign.id' => 'self.owner_id' });
 
 
 1;
