@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::Schema::ReportsDB::Result::View010TestrunOverviewReports::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Tapper::Schema::ReportsDB::Result::View010TestrunOverviewReports::VERSION = '4.0.2';
+  $Tapper::Schema::ReportsDB::Result::View010TestrunOverviewReports::VERSION = '4.1.0';
 }
 # the number is to sort classes on deploy
 
@@ -19,21 +19,25 @@ __PACKAGE__->table('view_testrun_overview_reports');
 
 # virtual is needed when the query should accept parameters
 __PACKAGE__->result_source_instance->is_virtual(0);
+__PACKAGE__->result_source_instance->deploy_depends_on( [qw(Tapper::Schema::ReportsDB::Result::ReportgroupTestrun
+                                                            Tapper::Schema::ReportsDB::Result::ReportgroupTestrunStats
+                                                          )] );
 __PACKAGE__->result_source_instance->view_definition
     (
-     "select rgts.testrun_id    as rgt_testrun_id, ".
-     "       max(rgt.report_id) as primary_report_id, ".
-     "       rgts.success_ratio as rgts_success_ratio ".
-     "from reportgrouptestrun rgt, reportgrouptestrunstats rgts ".
+     "select   rgt.testrun_id                  as rgt_testrun_id ".
+     "       , max(rgt.report_id)              as primary_report_id ".
+     "       , rgts.success_ratio              as rgts_success_ratio ".
+     "from reportgrouptestrun      rgt, ".
+     "     reportgrouptestrunstats rgts ".
      "where rgt.testrun_id=rgts.testrun_id ".
-     "group by rgt.testrun_id"
+     "group by rgt.testrun_id, rgts.success_ratio"
     );
 
 __PACKAGE__->add_columns
     (
-     'rgt_testrun_id'     => { data_type => 'INT',     is_auto_increment => 1 },
-     'rgts_success_ratio' => { data_type => 'varchar', size => 20             },
-     'primary_report_id'  => { data_type => 'INT'                             },
+     'rgt_testrun_id'     => { data_type => 'INT',                },
+     'rgts_success_ratio' => { data_type => 'varchar', size => 20 },
+     'primary_report_id'  => { data_type => 'INT'                 },
     );
 
 1;
