@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::Schema::TestrunDB::Result::Host::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Tapper::Schema::TestrunDB::Result::Host::VERSION = '4.0.2';
+  $Tapper::Schema::TestrunDB::Result::Host::VERSION = '4.1.0';
 }
 
 use 5.010;
@@ -30,9 +30,10 @@ __PACKAGE__->add_columns
 __PACKAGE__->set_primary_key("id");
 
 (my $basepkg = __PACKAGE__) =~ s/::\w+$//;
-
+__PACKAGE__->add_unique_constraint( constraint_name => [ qw/name/ ] );
 __PACKAGE__->has_many ( testrunschedulings => "${basepkg}::TestrunScheduling", { 'foreign.host_id' => 'self.id' });
 __PACKAGE__->has_many ( queuehosts         => "${basepkg}::QueueHost",         { 'foreign.host_id' => 'self.id' });
+__PACKAGE__->has_many ( denied_from_queue  => "${basepkg}::DeniedHost",        { 'foreign.host_id' => 'self.id' });
 __PACKAGE__->has_many ( features           => "${basepkg}::HostFeature",       { 'foreign.host_id' => 'self.id' });
 
 
